###########################################################################
#
# finalwidget.py
#
# A widget to display an image and a label containing a description.
#
# Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
#
# PyQt port in September 2010 by Hans-Peter Jansen <hpj@urpla.net>
#
###########################################################################

from PyQt4 import QtCore, QtGui

def tr(msg):
    return QtCore.QCoreApplication.translate("FinalWidget", msg)


class FinalWidget(QtGui.QFrame):

    def __init__(self, parent, name, labelSize):
        self.dragStartPosition = QtCore.QPoint()
        super(FinalWidget, self).__init__(parent)
        self.hasImage = False
        self.imageLabel = QtGui.QLabel()
        self.imageLabel.setFrameShadow(QtGui.QFrame.Sunken)
        self.imageLabel.setFrameShape(QtGui.QFrame.StyledPanel)
        self.imageLabel.setMinimumSize(labelSize)
        self.nameLabel = QtGui.QLabel(name)
        layout = QtGui.QVBoxLayout()
        layout.addWidget(self.imageLabel, 1)
        layout.addWidget(self.nameLabel, 0)
        self.setLayout(layout)


    def mouseMoveEvent(self, event):
        """ If the mouse moves far enough when the left mouse button is held down,
            start a drag and drop operation.
        """
        if not event.buttons() & QtCore.Qt.LeftButton:
            return
        if (event.pos() - self.dragStartPosition).manhattanLength() \
             < QtGui.QApplication.startDragDistance():
            return
        if not self.hasImage:
            return
        drag = QtGui.QDrag(self)
        mimeData = QtCore.QMimeData()

        output = QtCore.QByteArray()
        outputBuffer = QtCore.QBuffer(output)
        outputBuffer.open(QtCore.QIODevice.WriteOnly)
        self.imageLabel.pixmap().toImage().save(outputBuffer, "PNG")
        outputBuffer.close()
        mimeData.setData("image/png", output)
        #mimeData.setImageData(QVariant(*imageLabel.pixmap()))
        drag.setMimeData(mimeData)
        drag.setPixmap(self.imageLabel.pixmap().scaled(64, 64, QtCore.Qt.KeepAspectRatio))
        drag.setHotSpot(QtCore.QPoint(drag.pixmap().width() / 2,
                                      drag.pixmap().height()))
        drag.start()


    def mousePressEvent(self, event):
        """ Check for left mouse button presses in order to enable drag and drop. """
        if event.button() == QtCore.Qt.LeftButton:
            self.dragStartPosition = event.pos()


    def pixmap(self):
        return self.imageLabel.pixmap()


    def setPixmap(self, pixmap):
        self.imageLabel.setPixmap(pixmap)
        self.hasImage = True

